package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.domain.TElectronicFenceKey;
import com.ruoyi.system.domain.TElectronicFenceService;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-09-14
 */
public interface ITElectronicFenceKeyService {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TElectronicFenceKey selectTElectronicFenceKeyById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tElectronicFenceKey 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TElectronicFenceKey> selectTElectronicFenceKeyList(TElectronicFenceKey tElectronicFenceKey);

    /**
     * 新增【请填写功能名称】
     *
     * @param tElectronicFenceKey 【请填写功能名称】
     * @return 结果
     */
    public int insertTElectronicFenceKey(TElectronicFenceKey tElectronicFenceKey);

    /**
     * 修改【请填写功能名称】
     *
     * @param tElectronicFenceKey 【请填写功能名称】
     * @return 结果
     */
    public int updateTElectronicFenceKey(TElectronicFenceKey tElectronicFenceKey);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTElectronicFenceKeyByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTElectronicFenceKeyById(Long id);

    /**
     * 获取库中所有的key
     * @return
     */
    List<TElectronicFenceKey> selectTElectronicFenceKey();

    /**
     * 获取一个可用Key
     *
     * @return
     */
    TElectronicFenceKey selectAccessAvailableElectronicFenceKey();
}
