package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TElectronicFenceKey;
import com.ruoyi.system.service.ITElectronicFenceKeyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2023-09-14
 */
@RestController
@RequestMapping("/system/electronic/fence/key")
public class TElectronicFenceKeyController extends BaseController {
    @Autowired
    private ITElectronicFenceKeyService tElectronicFenceKeyService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:key:list')")
    @GetMapping("/list")
    public TableDataInfo list(TElectronicFenceKey tElectronicFenceKey) {
        startPage();
        List<TElectronicFenceKey> list = tElectronicFenceKeyService.selectTElectronicFenceKeyList(tElectronicFenceKey);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:key:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TElectronicFenceKey tElectronicFenceKey) {
        List<TElectronicFenceKey> list = tElectronicFenceKeyService.selectTElectronicFenceKeyList(tElectronicFenceKey);
        ExcelUtil<TElectronicFenceKey> util = new ExcelUtil<TElectronicFenceKey>(TElectronicFenceKey.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:key:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tElectronicFenceKeyService.selectTElectronicFenceKeyById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:key:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TElectronicFenceKey tElectronicFenceKey) {
        return toAjax(tElectronicFenceKeyService.insertTElectronicFenceKey(tElectronicFenceKey));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:key:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TElectronicFenceKey tElectronicFenceKey) {
        return toAjax(tElectronicFenceKeyService.updateTElectronicFenceKey(tElectronicFenceKey));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:key:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tElectronicFenceKeyService.deleteTElectronicFenceKeyByIds(ids));
    }
}
